/***************************************************************************//**
 *   @file   AD5754R.h
 *   @brief  Header file of AD5754R Driver.
 *   @author DNechita
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: $WCREV$
*******************************************************************************/

/******************************************************************************/
/* Include Files                                                              */
/******************************************************************************/
#include "Communication.h"

/******************************************************************************/
/* AD5754R                                                                     */
/******************************************************************************/
/* AD5754R GPIO */
#define AD5754R_LDAC_OUT    GPIO1_PIN_OUT
#define AD5754R_LDAC_LOW    GPIO1_LOW
#define AD5754R_LDAC_HIGH   GPIO1_HIGH
#define AD5754R_CLR_OUT     GPIO2_PIN_OUT
#define AD5754R_CLR_LOW     GPIO2_LOW
#define AD5754R_CLR_HIGH    GPIO2_HIGH

/* AD5754R Register Map */
#define AD5754R_REG_DAC             0x00 // DAC register
#define AD5754R_REG_RANGE_SELECT    0x01 // Output range select register
#define AD5754R_REG_POWER_CONTROL   0x02 // Power control register
#define AD5754R_REG_CONTROL         0x03 // Control register

/* AD5754R Channel Address */
#define AD5754R_DAC_A               0x00 // Address of channel A 
#define AD5754R_DAC_B               0x01 // Address of channel B
#define AD5754R_DAC_C               0x02 // Address of channel C
#define AD5754R_DAC_D               0x03 // Address of channel D
#define AD5754R_DAC_ALL             0x04 // All four DACs 

/* AD5754R Range Bits */
#define AD5754R_UNIPOLAR_5_RANGE    0x00 // 0..+5(V)        
#define AD5754R_UNIPOLAR_10_RANGE   0x01 // 0..+10(V)       
#define AD5754R_UNIPOLAR_10_8_RANGE 0x02 // 0..+10.8(V)     
#define AD5754R_BIPOLAR_5_RANGE     0x03 // -5..+5(V)       
#define AD5754R_BIPOLAR_10_RANGE    0x04 // -10...+10(V)    
#define AD5754R_BIPOLAR_10_8_RANGE  0x05 // -10.8...+10.8(V) 

/* Control Functions */
#define AD5754R_NOP_OPERATION       0x00 // No operation instruction used in readback operations.
#define AD5754R_SDO_DISABLE         0x11 // Set by the user to disable the SDO output.
#define AD5754R_CLR_SELECT          0x12 // Selects the clear code: 0V, Midscale or Negative full scale.
#define AD5754R_CLAMP_ENABLE        0x14 // Set by the user to enable the current-limit clamp.
#define AD5754R_TSD_ENABLE          0x18 // Set by the user to enable the thermal shutdown feature.
#define AD5754R_CLEAR               0x40 // Sets the DAC registers to the clear code and updates the outputs.
#define AD5754R_LOAD                0x50 // Updates the DAC registers and, consequently, the DAC outputs.

/******************************************************************************/
/* Functions Prototypes                                                       */
/******************************************************************************/
/* Initializes the SPI. */
unsigned char AD5754R_Init(void);			    

/* Writes data into a register. */
void AD5754R_SetRegisterValue(unsigned char regBits,
                             unsigned char adrBits,
                             unsigned short registerValue);

/* Reads the value of a register. */
unsigned short AD5754R_GetRegisterValue(unsigned char regBits,
                                       unsigned char adrBits);

/* Enables/disables indicated DAC channels. */
void AD5754R_SetPower(unsigned char dacChannel,
                      unsigned char onOff);

/* Writes data into a DAC channel register. */
void AD5754R_LoadDac(unsigned char dacChannel,
                     unsigned short dacValue);

/* Selects the output range of a DAC channel. */
void AD5754R_RangeSelect(unsigned char dacChannel,
                         unsigned char outputRange);

/* Selects an option of Control Register. */
void AD5754R_ControlFunction(unsigned char option,
                             unsigned char bitValue);

/* Reads alert bits form Power Control Register. */
unsigned char AD5754R_ReadAlertBits(void);
